.. title:: User guide : contents

.. _user_guide:

==========
User guide
==========

Under construction
------------------

This user guide is under construction. Please be patient while we update it
or suggest your own edits by `opening an issue
<https://github.com/richford/groupyr/issues>`_.